@@ -1,7 +1,7 @@
 package PAUSE::Packages;
-$PAUSE::Packages::VERSION = '0.16';
-use 5.10.0;
-use autodie qw(open);
+$PAUSE::Packages::VERSION = '0.17';
+use 5.8.1;
+use autodie 2.29 qw(open);
 
 use Moo 1.006;
 
